.. _api_xmlrpc:

XMLRPC
======


.. toctree::
   :maxdepth: 2


Authentication
--------------

.. automodule:: tcms.xmlrpc.api.auth
   :members:

TestBuild
---------

.. automodule:: tcms.xmlrpc.api.build
   :members:

Env
---

.. automodule:: tcms.xmlrpc.api.env
   :members:

Product
-------

.. automodule:: tcms.xmlrpc.api.product
   :members:

Tag
---

.. automodule:: tcms.xmlrpc.api.tag
   :members:

TestPlan
--------

.. automodule:: tcms.xmlrpc.api.testplan
   :members:

TestCase
--------

.. automodule:: tcms.xmlrpc.api.testcase
   :members:

TestCasePlan
------------

.. automodule:: tcms.xmlrpc.api.testcaseplan
   :members:

TestRun
-------

.. automodule:: tcms.xmlrpc.api.testrun
   :members:

TestCaseRun
-----------

.. automodule:: tcms.xmlrpc.api.testcaserun
   :members:

Version
-------

.. automodule:: tcms.xmlrpc.api.version
   :members:

User
----

.. automodule:: tcms.xmlrpc.api.user
   :members:

testopia
-----------

.. automodule:: tcms.xmlrpc.api.testopia
   :members:
